==> libzypp-docs-17.37.2-2-x86_64.pkg.tar.zst: usr/share/doc/libzypp/html/autodoc/html/classzyppng_1_1ProvideFileSpec.js <==
var classzyppng_1_1ProvideFileSpec =
[
    [ "Impl", "classzyppng_1_1ProvideFileSpec_1_1Impl.html", "classzyppng_1_1ProvideFileSpec_1_1Impl" ],
    [ "ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#a1547cef58c8c282a032022d5e33514ae", null ],
    [ "ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#a5a7d3cec7b8142c00f37c0f0effec556", null ],
    [ "ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#a9f5c64167b9c65bf03848900bbcdc17f", null ],
    [ "ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#ae1dffad05ebfe32ffffe8e9b530e0912", null ],
    [ "~ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#a2c44aa2d06ce80ea2ef91b8811fe2c56", null ],
    [ "operator=", "classzyppng_1_1ProvideFileSpec.html#a15c3b8a33e029e155db16251bc3ed0eb", null ],
    [ "operator=", "classzyppng_1_1ProvideFileSpec.html#a9c02380ece40166a5de6f3fb724b76a5", null ],
    [ "create", "classzyppng_1_1ProvideFileSpec.html#ac91b9c000f618a865d1addbb951fe784", null ],
    [ "destFilenameHint", "classzyppng_1_1ProvideFileSpec.html#a4cc9d87144b938498fbd07c5f7ed201a", null ],
    [ "setDestFilenameHint", "classzyppng_1_1ProvideFileSpec.html#ab7e78cd0130ca47ff31fc6e7013fc971", null ],
    [ "checkExistsOnly", "classzyppng_1_1ProvideFileSpec.html#aef02bbf3da92a9f778e645ef221d7dbc", null ],
    [ "setCheckExistsOnly", "classzyppng_1_1ProvideFileSpec.html#a2c2f4a99ae14a1d40f460b561ff878a2", null ],
    [ "optional", "classzyppng_1_1ProvideFileSpec.html#a1833b344309d47a964845319f404a11b", null ],
    [ "setOptional", "classzyppng_1_1ProvideFileSpec.html#a54d4acacba73c9fc44a3b084485718f9", null ],
    [ "downloadSize", "classzyppng_1_1ProvideFileSpec.html#a805608b1a2dff7c0dc110c4c70425f40", null ],
    [ "setDownloadSize", "classzyppng_1_1ProvideFileSpec.html#acc14fa27a8f3dd51b8344ccdd3fff47e", null ],
    [ "checksum", "classzyppng_1_1ProvideFileSpec.html#abd9c4d6704579e11ee5853b329c086ad", null ],
    [ "setChecksum", "classzyppng_1_1ProvideFileSpec.html#a91408d5bd8f25fd5a854a4d45e1cd229", null ],
    [ "openSize", "classzyppng_1_1ProvideFileSpec.html#a9bb8aa8ebc8d2ec401d315c5a6f3e810", null ],
    [ "setOpenSize", "classzyppng_1_1ProvideFileSpec.html#a83bbdd1b5632a527e60e89d1d0116489", null ],
    [ "openChecksum", "classzyppng_1_1ProvideFileSpec.html#a22c671e43b2012c416f9c7d8642d6b5f", null ],
    [ "setOpenChecksum", "classzyppng_1_1ProvideFileSpec.html#a9f25b1842dced7011f82788e245b8960", null ],
    [ "headerSize", "classzyppng_1_1ProvideFileSpec.html#ae2d53b805f81dac5c9c683318ff23f1c", null ],
    [ "setHeaderSize", "classzyppng_1_1ProvideFileSpec.html#ad59f21caf102f4cb0ffb186c658c48a0", null ],
    [ "headerChecksum", "classzyppng_1_1ProvideFileSpec.html#ad175ea28b7c0592e94e907df4146752b", null ],
    [ "setHeaderChecksum", "classzyppng_1_1ProvideFileSpec.html#a1e18280405908d15f55f2c756b66aafc", null ],
    [ "deltafile", "classzyppng_1_1ProvideFileSpec.html#ab62709e5ca801c5a84fe16e137aca83b", null ],
    [ "setDeltafile", "classzyppng_1_1ProvideFileSpec.html#a2a19cf960232bd75e5c9a85c3f000b18", null ],
    [ "customHeaders", "classzyppng_1_1ProvideFileSpec.html#a34895fcf93965088fc892c234834f40d", null ],
    [ "customHeaders", "classzyppng_1_1ProvideFileSpec.html#a5cc1a8c1dc7a1e94faa78cee883198d6", null ],
    [ "setCustomHeaderValue", "classzyppng_1_1ProvideFileSpec.html#a2705690e5ca9dbda74a9cce77106402b", null ],
    [ "addCustomHeaderValue", "classzyppng_1_1ProvideFileSpec.html#add64c16e4d19ac7f1b4d8d1817354900", null ],
    [ "asOnMediaLocation", "classzyppng_1_1ProvideFileSpec.html#a83b1a204456b2e24c444f9d976b671f3", null ],
    [ "operator<<", "classzyppng_1_1ProvideFileSpec.html#a6be0e3c16eb03e75fb945c10eeb4bdb7", null ],
    [ "dumpOn", "classzyppng_1_1ProvideFileSpec.html#ad9fe56dcc807502193a5f97c7dc78e62", null ],
    [ "_pimpl", "classzyppng_1_1ProvideFileSpec.html#abcc7fe1f0d32aa2b36844360ab0fe846", null ]
];

==> libzypp-docs-17.37.18-2-x86_64.pkg.tar.zst: usr/share/doc/libzypp/html/autodoc/html/classzyppng_1_1ProvideFileSpec.js <==
var classzyppng_1_1ProvideFileSpec =
[
    [ "Impl", "classzyppng_1_1ProvideFileSpec_1_1Impl.html", "classzyppng_1_1ProvideFileSpec_1_1Impl" ],
    [ "ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#a1547cef58c8c282a032022d5e33514ae", null ],
    [ "ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#a5a7d3cec7b8142c00f37c0f0effec556", null ],
    [ "ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#a9f5c64167b9c65bf03848900bbcdc17f", null ],
    [ "ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#ae1dffad05ebfe32ffffe8e9b530e0912", null ],
    [ "~ProvideFileSpec", "classzyppng_1_1ProvideFileSpec.html#a2c44aa2d06ce80ea2ef91b8811fe2c56", null ],
    [ "operator=", "classzyppng_1_1ProvideFileSpec.html#a15c3b8a33e029e155db16251bc3ed0eb", null ],
    [ "operator=", "classzyppng_1_1ProvideFileSpec.html#a9c02380ece40166a5de6f3fb724b76a5", null ],
    [ "create", "classzyppng_1_1ProvideFileSpec.html#ac91b9c000f618a865d1addbb951fe784", null ],
    [ "destFilenameHint", "classzyppng_1_1ProvideFileSpec.html#a4cc9d87144b938498fbd07c5f7ed201a", null ],
    [ "setDestFilenameHint", "classzyppng_1_1ProvideFileSpec.html#ab7e78cd0130ca47ff31fc6e7013fc971", null ],
    [ "checkExistsOnly", "classzyppng_1_1ProvideFileSpec.html#aef02bbf3da92a9f778e645ef221d7dbc", null ],
    [ "setCheckExistsOnly", "classzyppng_1_1ProvideFileSpec.html#a2c2f4a99ae14a1d40f460b561ff878a2", null ],
    [ "optional", "classzyppng_1_1ProvideFileSpec.html#a1833b344309d47a964845319f404a11b", null ],
    [ "setOptional", "classzyppng_1_1ProvideFileSpec.html#a54d4acacba73c9fc44a3b084485718f9", null ],
    [ "downloadSize", "classzyppng_1_1ProvideFileSpec.html#a805608b1a2dff7c0dc110c4c70425f40", null ],
    [ "setDownloadSize", "classzyppng_1_1ProvideFileSpec.html#acc14fa27a8f3dd51b8344ccdd3fff47e", null ],
    [ "checksum", "classzyppng_1_1ProvideFileSpec.html#abd9c4d6704579e11ee5853b329c086ad", null ],
    [ "setChecksum", "classzyppng_1_1ProvideFileSpec.html#a91408d5bd8f25fd5a854a4d45e1cd229", null ],
    [ "openSize", "classzyppng_1_1ProvideFileSpec.html#a9bb8aa8ebc8d2ec401d315c5a6f3e810", null ],
    [ "setOpenSize", "classzyppng_1_1ProvideFileSpec.html#a83bbdd1b5632a527e60e89d1d0116489", null ],
    [ "openChecksum", "classzyppng_1_1ProvideFileSpec.html#a22c671e43b2012c416f9c7d8642d6b5f", null ],
    [ "setOpenChecksum", "classzyppng_1_1ProvideFileSpec.html#a9f25b1842dced7011f82788e245b8960", null ],
    [ "headerSize", "classzyppng_1_1ProvideFileSpec.html#ae2d53b805f81dac5c9c683318ff23f1c", null ],
    [ "setHeaderSize", "classzyppng_1_1ProvideFileSpec.html#ad59f21caf102f4cb0ffb186c658c48a0", null ],
    [ "headerChecksum", "classzyppng_1_1ProvideFileSpec.html#ad175ea28b7c0592e94e907df4146752b", null ],
    [ "setHeaderChecksum", "classzyppng_1_1ProvideFileSpec.html#a1e18280405908d15f55f2c756b66aafc", null ],
    [ "deltafile", "classzyppng_1_1ProvideFileSpec.html#ab62709e5ca801c5a84fe16e137aca83b", null ],
    [ "setDeltafile", "classzyppng_1_1ProvideFileSpec.html#a2a19cf960232bd75e5c9a85c3f000b18", null ],
    [ "mirrorsAllowed", "classzyppng_1_1ProvideFileSpec.html#a97f1d1343dd29c9452b4aa2a45a44611", null ],
    [ "setMirrorsAllowed", "classzyppng_1_1ProvideFileSpec.html#a84acd0856652f272d868f9b43c105ef9", null ],
    [ "customHeaders", "classzyppng_1_1ProvideFileSpec.html#a34895fcf93965088fc892c234834f40d", null ],
    [ "customHeaders", "classzyppng_1_1ProvideFileSpec.html#a5cc1a8c1dc7a1e94faa78cee883198d6", null ],
    [ "setCustomHeaderValue", "classzyppng_1_1ProvideFileSpec.html#a2705690e5ca9dbda74a9cce77106402b", null ],
    [ "addCustomHeaderValue", "classzyppng_1_1ProvideFileSpec.html#add64c16e4d19ac7f1b4d8d1817354900", null ],
    [ "asOnMediaLocation", "classzyppng_1_1ProvideFileSpec.html#a83b1a204456b2e24c444f9d976b671f3", null ],
    [ "operator<<", "classzyppng_1_1ProvideFileSpec.html#a6be0e3c16eb03e75fb945c10eeb4bdb7", null ],
    [ "dumpOn", "classzyppng_1_1ProvideFileSpec.html#ad9fe56dcc807502193a5f97c7dc78e62", null ],
    [ "_pimpl", "classzyppng_1_1ProvideFileSpec.html#abcc7fe1f0d32aa2b36844360ab0fe846", null ]
];
